@@ -42,7 +42,7 @@ details. */
 	 the Cygwin shared library".  This version is used to track important
 	 changes to the DLL and is mainly informative in nature. */
 
-#define CYGWIN_VERSION_DLL_MAJOR 2002
+#define CYGWIN_VERSION_DLL_MAJOR 2003
 #define CYGWIN_VERSION_DLL_MINOR 1
 
       /* Major numbers before CYGWIN_VERSION_DLL_EPOCH are
@@ -471,13 +471,15 @@ details. */
       287: Export issetugid.
       288: Export getcontext, makecontext, setcontext, swapcontext.
       289: Export sigsetjmp, siglongjmp.
+      290: Add sysconf cache handling.
+      291: Export aligned_alloc, at_quick_exit, quick_exit.
      */
 
      /* Note that we forgot to bump the api for ualarm, strtoll, strtoull,
 	sigaltstack, sethostname. */
 
 #define CYGWIN_VERSION_API_MAJOR 0
-#define CYGWIN_VERSION_API_MINOR 289
+#define CYGWIN_VERSION_API_MINOR 291
 
      /* There is also a compatibity version number associated with the
 	shared memory regions.  It is incremented when incompatible
